@@ -5,8 +5,8 @@
 ;; Author:   Dmitry Gutov <dmitry@gutov.dev>
 ;; URL:      https://github.com/dgutov/diff-hl
 ;; Keywords: vc, diff
-;; Package-Version: 20251126.112
-;; Package-Revision: 685ea2d50607
+;; Package-Version: 20251216.242
+;; Package-Revision: e79aa49ad3cb
 ;; Package-Requires: ((cl-lib "0.2") (emacs "26.1"))
 
 ;; This file is part of GNU Emacs.
@@ -422,7 +422,8 @@ It can be a relative expression as well, such as \"HEAD^\" with Git, or
   (or (memq state '(edited conflict))
       (and (eq state 'up-to-date)
            ;; VC state is stale in after-revert-hook.
-           (or (static-if (>= emacs-major-version 31)
+           (or (static-if (boundp 'revert-buffer-in-progress)
+                   ;; Emacs 31.
                    revert-buffer-in-progress
                  revert-buffer-in-progress-p)
                ;; Diffing against an older revision.
@@ -741,9 +742,14 @@ Return a list of line overlays used."
 (defun diff-hl--resolve (value-or-buffer cb)
   (if (listp value-or-buffer)
       (funcall cb value-or-buffer)
-    (diff-hl--when-done value-or-buffer
-                        #'diff-hl-changes-from-buffer
-                        cb)))
+    (static-if (fboundp 'vc-run-delayed-success)
+        ;; Emacs 31.
+        (with-current-buffer value-or-buffer
+          (vc-run-delayed-success 1
+            (funcall cb (diff-hl-changes-from-buffer (current-buffer)))))
+      (diff-hl--when-done value-or-buffer
+                          #'diff-hl-changes-from-buffer
+                          cb))))
 
 (defun diff-hl--when-done (buffer get-value callback &optional proc)
   (let ((proc (or proc (get-buffer-process buffer))))
